local SM = AceLibrary("SharedMedia-1.0")

function CBRipoff:CreateFramework(b, n, s)
	self.frames[b] = CreateFrame("Frame", n, UIParent)

	local frame = self.frames[b]

	frame:Hide()
	frame.name = b
	
	if(s =="MirrorBar") then
		frame:SetScript("OnUpdate", self.OnMirror)
	else
		frame:SetScript("OnUpdate", self.OnCasting)
	end
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:RegisterForDrag("LeftButton")
	frame:SetScript("OnDragStart", function() if not self.db.profile.lock then this:StartMoving() end end)
	frame:SetScript("OnDragStop", function() this:StopMovingOrSizing() self:savePosition() end)
	
	frame.Bar = CreateFrame("StatusBar", nil, frame)
	frame.Spark = frame.Bar:CreateTexture(nil, "OVERLAY")
	frame.Time = frame.Bar:CreateFontString(nil, "OVERLAY")
	frame.Spell = frame.Bar:CreateFontString(nil, "OVERLAY")
	if(s ~="MirrorBar") then
		frame.Delay = frame.Bar:CreateFontString(nil, "OVERLAY")
		frame.Icon = frame.Bar:CreateTexture(nil, "OVERLAY")
	end
	
	self:Layout(b, s)
end

function CBRipoff:Layout(b, s)
	local db = self.db.profile[s or b]
	local f, _ = GameFontHighlightSmall:GetFont()
	
	local frame = self.frames[b]

	frame:SetWidth(db.width+9)
	frame:SetHeight(db.height+10)
	frame:SetBackdrop({
		bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = true, tileSize = 16,
		edgeFile = self.Borders[db.edgeFile], edgeSize = 16,
		insets = {left = 4, right = 4, top = 4, bottom = 4},
	})
	frame:SetBackdropBorderColor(0, 0, 0)
	frame:SetBackdropColor(0, 0, 0)
	
	frame.Bar:ClearAllPoints()
	frame.Bar:SetPoint("CENTER", frame, "CENTER", 0, 0)
	frame.Bar:SetWidth(db.width)
	frame.Bar:SetHeight(db.height)
	frame.Bar:SetStatusBarTexture(SM:Fetch("statusbar", db.texture))
	
	frame.Spark:SetTexture("Interface\\CastingBar\\UI-CastingBar-Spark")
	frame.Spark:SetWidth(16)
	frame.Spark:SetHeight(db.height*2.44)
	frame.Spark:SetBlendMode("ADD")
	
	frame.Time:SetJustifyH("RIGHT")
	frame.Time:SetFont(f,db.timeSize)
	frame.Time:SetText("X.Y")
	frame.Time:ClearAllPoints()
	frame.Time:SetPoint("RIGHT", frame.Bar, "RIGHT",-10,0)
	frame.Time:SetShadowOffset(.8, -.8)
	frame.Time:SetShadowColor(0, 0, 0, 1)
	
	frame.Spell:SetJustifyH("CENTER")
	frame.Spell:SetWidth(db.width-frame.Time:GetWidth())
	frame.Spell:SetFont(f,db.spellSize)
	frame.Spell:ClearAllPoints()
	frame.Spell:SetPoint("LEFT", frame, "LEFT",10,0)
	frame.Spell:SetShadowOffset(.8, -.8)
	frame.Spell:SetShadowColor(0, 0, 0, 1)
	
	if(s ~="MirrorBar") then
		frame.Delay:SetTextColor(1,0,0,1)
		frame.Delay:SetJustifyH("RIGHT")
		frame.Delay:SetFont(f,db.delaySize)
		frame.Delay:SetText("X.Y")
		frame.Delay:ClearAllPoints()
		frame.Delay:SetPoint("TOPRIGHT", frame, "TOPRIGHT",-10,20)
		frame.Delay:SetShadowOffset(.8, -.8)
		frame.Delay:SetShadowColor(0, 0, 0, 1)

		frame.Icon:SetTexture("Interface\\CastingBar\\UI-CastingBar-Spark")
		frame.Icon:SetWidth(db.height)
		frame.Icon:SetHeight(db.height)
		frame.Icon:ClearAllPoints()
		if db.icon == "Left"  then
			frame.Icon:SetPoint("BOTTOMRIGHT", frame, "BOTTOMLEFT", -2, 5)
		elseif db.icon == "Right" then
			frame.Icon:SetPoint("BOTTOMLEFT", frame, "BOTTOMRIGHT", 2, 5)
		elseif db.icon == "None" then
			frame.Icon:Hide()
		end
	end
	
	self:updatePositions(b)
end

function CBRipoff:ShowBlizzCB()
	CastingBarFrame["Show"] = self.BlizzShow
end

function CBRipoff:HideBlizzCB()
	if(not self.BlizzShow) then self.BlizzShow = CastingBarFrame["Show"] end
	CastingBarFrame["Show"] = function() end
end

